@@ -135,7 +135,7 @@ select              =
 'If `index` is a number, returns all arguments after argument number `index`; a negative number indexes from the end (`-1` is the last argument). Otherwise, `index` must be the string `"#"`, and `select` returns the total number of extra arguments it received.'
 
 setfenv             =
-'Sets the environment to be used by the given function. '
+'Sets the environment to be used by the given function.'
 
 setmetatable        =
 [[
@@ -519,11 +519,11 @@ math.log10                  =
 'Returns the base-10 logarithm of x.'
 math.max                    =
 'Returns the argument with the maximum value, according to the Lua operator `<`.'
-math.maxinteger             =
+math.maxinteger['>5.3']     =
 'An integer with the maximum value for an integer.'
 math.min                    =
 'Returns the argument with the minimum value, according to the Lua operator `<`.'
-math.mininteger             =
+math.mininteger['>5.3']     =
 'An integer with the minimum value for an integer.'
 math.modf                   =
 'Returns the integral part of `x` and the fractional part of `x`.'
@@ -557,11 +557,11 @@ math.tan                    =
 'Returns the tangent of `x` (assumed to be in radians).'
 math.tanh                   =
 'Returns the hyperbolic tangent of `x` (assumed to be in radians).'
-math.tointeger              =
+math.tointeger['>5.3']      =
 'If the value `x` is convertible to an integer, returns that integer.'
-math.type                   =
+math.type['>5.3']           =
 'Returns `"integer"` if `x` is an integer, `"float"` if it is a float, or `nil` if `x` is not a number.'
-math.ult                    =
+math.ult['>5.3']            =
 'Returns `true` if and only if `m` is below `n` when they are compared as unsigned integers.'
 
 os                          =
@@ -647,13 +647,15 @@ string.char                 =
 'Returns a string with length equal to the number of arguments, in which each character has the internal numeric code equal to its corresponding argument.'
 string.dump                 =
 'Returns a string containing a binary representation (a *binary chunk*) of the given function.'
-string.find                 =
+string.find['>5.2']         =
 'Looks for the first match of `pattern` (see §6.4.1) in the string.'
+string.find['=5.1']         =
+'Looks for the first match of `pattern` (see §5.4.1) in the string.'
 string.format               =
 'Returns a formatted version of its variable number of arguments following the description given in its first argument.'
-string.gmatch               =
+string.gmatch['>5.2']       =
 [[
-Returns an iterator function that, each time it is called, returns the next captures from `pattern` (see §6.4.1) over the string s. 
+Returns an iterator function that, each time it is called, returns the next captures from `pattern` (see §6.4.1) over the string s.
 
 As an example, the following loop will iterate over all the words from string s, printing one per line:
 ```lua
@@ -664,17 +666,34 @@ As an example, the following loop will iterate over all the words from string s,
     end
 ```
 ]]
-string.gsub                 =
+string.gmatch['=5.1']       =
+[[
+Returns an iterator function that, each time it is called, returns the next captures from `pattern` (see §5.4.1) over the string s.
+
+As an example, the following loop will iterate over all the words from string s, printing one per line:
+```lua
+    s =
+"hello world from Lua"
+    for w in string.gmatch(s, "%a+") do
+        print(w)
+    end
+```
+]]
+string.gsub['>5.2']         =
 'Returns a copy of s in which all (or the first `n`, if given) occurrences of the `pattern` (see §6.4.1) have been replaced by a replacement string specified by `repl`.'
+string.gsub['=5.1']         =
+'Returns a copy of s in which all (or the first `n`, if given) occurrences of the `pattern` (see §5.4.1) have been replaced by a replacement string specified by `repl`.'
 string.len                  =
 'Returns its length.'
 string.lower                =
 'Returns a copy of this string with all uppercase letters changed to lowercase.'
-string.match                =
+string.match['>5.2']        =
 'Looks for the first match of `pattern` (see §6.4.1) in the string.'
-string.pack                 =
+string.match['=5.1']        =
+'Looks for the first match of `pattern` (see §5.4.1) in the string.'
+string.pack['>5.2']         =
 'Returns a binary string containing the values `v1`, `v2`, etc. packed (that is, serialized in binary form) according to the format string `fmt` (see §6.4.2) .'
-string.packsize             =
+string.packsize['>5.2']     =
 'Returns the size of a string resulting from `string.pack` with the given format string `fmt` (see §6.4.2) .'
 string.rep['>5.2']          =
 'Returns a string that is the concatenation of `n` copies of the string `s` separated by the string `sep`.'
@@ -726,6 +745,19 @@ table.foreachi              =
 'Executes the given f over the numerical indices of table. For each index, f is called with the index and respective value as arguments. Indices are visited in sequential order, from 1 to n, where n is the size of the table. If f returns a non-nil value, then the loop is broken and this value is returned as the result of foreachi.'
 table.getn                  =
 'Returns the number of elements in the table. This function is equivalent to `#list`.'
+table.new                   =
+[[This creates a pre-sized table, just like the C API equivalent `lua_createtable()`. This is useful for big tables if the final table size is known and automatic table resizing is too expensive. `narray` parameter specifies the number of array-like items, and `nhash` parameter specifies the number of hash-like items. The function needs to be required before use.
+```lua
+    require("table.new")
+```
+]]
+table.clear                 =
+[[This clears all keys and values from a table, but preserves the allocated array/hash sizes. This is useful when a table, which is linked from multiple places, needs to be cleared and/or when recycling a table for use by the same context. This avoids managing backlinks, saves an allocation and the overhead of incremental array/hash part growth. The function needs to be required before use.
+```lua
+    require("table.clear").
+```
+Please note this function is meant for very specific situations. In most cases it's better to replace the (usually single) link with a new table and let the GC do its work.
+]]
 
 utf8                        =
 ''
