@@ -665,7 +665,6 @@ string.lower                =
 '文字列内のすべての大文字を小文字に取り換えた文字列を返す。'
 string.match                =
 '文字列の中から `pattern` に最初にマッチした部分を返す（§6.4.1 を参照）。マッチしたものがない場合、`nil` を返す。'
-'文字列 `s` の中で `pattern`（§6.4.1 を参照）に一致する最初の部分を見つける。見つかった場合、そのキャプチャされた値を返す。見つからなければ `nil` を返す。'
 string.pack                 =
 '第一引数で指定されたフォーマットに沿って、可変数の引数をバイナリ文字列にシリアライズしたものを返す（§6.4.2 を参照）。'
 string.packsize             =
@@ -744,7 +743,7 @@ utf8                        =
 utf8.char                   =
 '0個以上の整数を受け取り、それぞれを対応するUTF-8文字に変換し、これらの文字を連結した文字列を返す。'
 utf8.charpattern            =
-'1つのUTF-8文字にマッチするパターンを返す。このパターンを用いる際には、対象の文字列が有効なUTF-8文字列である必要がある。
+'1つのUTF-8文字にマッチするパターンを返す。このパターンを用いる際には、対象の文字列が有効なUTF-8文字列である必要がある。'
 utf8.codes                  =
 [[
 次の構文において`p`が各UTF-8文字のバイト位置、`c`が各UTF-8文字の文字コードとなるような値を返す。無効なバイトシーケンスが文字列に含まれた場合にはエラーを出す。
