@@ -4,11 +4,14 @@ local vm       = require 'vm.vm'
 
 ---@param source parser.object?
 ---@return boolean|nil
-function vm.test(source)
+function vm.testCondition(source)
     if not source then
         return nil
     end
     local node = vm.compileNode(source)
+    if node.optional then
+        return nil
+    end
     local hasTrue, hasFalse
     for n in node:eachObject() do
         if n.type == 'boolean'
@@ -19,24 +22,20 @@ function vm.test(source)
             if n[1] == false then
                 hasFalse = true
             end
-        end
-        if n.type == 'global' and n.cate == 'type' then
-            if n.name == 'true' then
-                hasTrue = true
+        elseif n.type == 'global' and n.cate == 'type' then
+            if n.name == 'boolean'
+            or n.name == 'unknown' then
+                return nil
             end
             if n.name == 'false'
             or n.name == 'nil' then
                 hasFalse = true
+            else
+                hasTrue = true
             end
-        end
-        if n.type == 'nil' then
+        elseif n.type == 'nil' then
             hasFalse = true
-        end
-        if n.type == 'string'
-        or n.type == 'number'
-        or n.type == 'integer'
-        or n.type == 'table'
-        or n.type == 'function' then
+        elseif guide.isLiteral(n) then
             hasTrue = true
         end
     end
@@ -50,8 +49,8 @@ function vm.test(source)
     end
 end
 
----@param v vm.object
----@return string?
+---@param v vm.node.object
+---@return string|false
 local function getUnique(v)
     if v.type == 'boolean' then
         if v[1] == nil then
@@ -72,16 +71,18 @@ local function getUnique(v)
         return ('num:%s'):format(v[1])
     end
     if v.type == 'table' then
+        ---@cast v parser.object
         return ('table:%s@%d'):format(guide.getUri(v), v.start)
     end
     if v.type == 'function' then
+        ---@cast v parser.object
         return ('func:%s@%d'):format(guide.getUri(v), v.start)
     end
     return false
 end
 
----@param a vm.object?
----@param b vm.object?
+---@param a parser.object?
+---@param b parser.object?
 ---@return boolean|nil
 function vm.equal(a, b)
     if not a or not b then
@@ -141,7 +142,7 @@ function vm.getInteger(v)
 end
 
 ---@param v vm.object?
----@return integer?
+---@return string?
 function vm.getString(v)
     if not v then
         return nil
@@ -212,11 +213,13 @@ end
 
 ---@param v vm.object
 ---@return table<any, boolean>?
+---@return integer
 function vm.getLiterals(v)
     if not v then
-        return nil
+        return nil, 0
     end
     local map
+    local count = 0
     local node = vm.compileNode(v)
     for n in node:eachObject() do
         local literal
@@ -236,7 +239,8 @@ function vm.getLiterals(v)
                 map = {}
             end
             map[literal] = true
+            count = count + 1
         end
     end
-    return map
+    return map, count
 end
